@@ -1,3 +1,21 @@
+############################################################################
+##      Copyright (C) 2005 Subredu Manuel  <diablo@iasi.roedu.net>.        #
+##                                                                         #
+## This program is free software; you can redistribute it and/or modify    #
+## it under the terms of the GNU General Public License v2 as published by #
+## the Free Software Foundation.                                           #
+##                                                                         #
+## This program is distributed in the hope that it will be useful,         #
+## but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+## GNU General Public License for more details.                            #
+##                                                                         #
+## You should have received a copy of the GNU General Public License       #
+## along with this program; if not, write to the Free Software             #
+## Foundation, Inc., 59 Temple Place - Suite 330, Boston,                  #
+## MA 02111-1307,USA.                                                      #
+############################################################################
+
 package RoPkg::Simba;
 
 use warnings;
@@ -5,7 +23,7 @@ use strict;
 
 use vars qw($VERSION $cfg $SimbaURL);
 
-$VERSION='0.8.4';
+$VERSION='0.8';
 $SimbaURL='http://simba.packages.ro';
 
 use Data::Dumper;
@@ -16,7 +34,6 @@ use Module::Pluggable instantiate => 'new';
 use English      qw( -no_match_vars );
 use Scalar::Util qw(blessed);
 use Log::Log4perl;
-use Number::Format;
 
 use RoPkg::DB;
 use RoPkg::Exceptions;
@@ -190,26 +207,6 @@ sub dbo_method {
   return 'db_mirrors';
 }
 
-sub CheckDB {
-  my ($self) = @_;
-  my $ret_value = 0;
-
-  my $mirrors_no  = $self->MirrorsNo();
-  my $commands_no = $self->CommandsNo();
-
-  if ($mirrors_no == 0) {
-    print 'Whoops ! No mirrors found in database', $RS;
-    $ret_value++;
-  }
-
-  if ($commands_no == 0) {
-    print 'Whoops ! No commands found in database', $RS;
-    $ret_value++;
-  }
-
-  return $ret_value;
-}
-
 sub MirrorsNo {
   my ($self, $fields) = @_;
 
@@ -313,7 +310,7 @@ sub LoadMirror {
     }
   }
 
-  return ($mirror, $command, $excludes);
+  return wantarray ? ($mirror, $command, $excludes) : $mirror;
 }
 
 ### Load and check (lac) mirror from database...
@@ -335,11 +332,11 @@ sub _lac_mirror {
     my $m = $_;
 
     if ( ! $mirror->$m ) {
-      $self->{log}->error('Mirror ',$mirror->Name,' has ',$m,' undefined');
       Mirror::Config->throw(
         error    => 'Mirror has undefined field: ' . $m,
         pkg_name => ref $self
       );
+      $self->{log}->error('Mirror ',$mirror->Name,' has ',$m,' undefined');
     }
   }
 
@@ -742,7 +739,7 @@ sub RunCallbacks {
       my $method_name = $_;
 
       $self->{log}->debug('Calling ', ref $pobj,'->',$method_name);
-      $pobj->$method_name($cfg, \@mirrors);
+      $pobj->$method_name($cfg, @mirrors);
     }
   }
 
@@ -817,13 +814,11 @@ sub _get_fields_string {
   return $fields_desc;
 }
 
-# Loads the mirror from the database, along with Command and Excludes.
-# Returns a array ($mirror, $command, $excludes)
-# Throws a lot of exceptions. All catched exceptions are rethrowed
-sub _load_mirror {
+sub Run {
   my ($self, $fields) = @_;
-  my ($m, $c, $e);
-  
+  my ($mirror, $command, $exclude);
+  my $cmdstr;
+
   if ( !blessed($self) ) {
     OutsideClass->throw('Called from outside class');
   }
@@ -831,17 +826,17 @@ sub _load_mirror {
   $self->{log}->info('Loading mirror {',$self->_get_fields_string($fields),'}');
   
   eval {
-    ($m, $c, $e) = $self->LoadMirror($fields);
+    ($mirror, $command, $exclude) = $self->LoadMirror($fields);
   };
 
   if (my $e = Exception::Class->caught('DB::NoResults')) {
     if ( $e->pkg_name eq 'RoPkg::Simba::Mirrors' ) {
       $self->{log}->error('Mirror ',$self->_get_fields_string($fields),' not found in database');
-      $e->rethrow;
+      return 1;
     }
     elsif ( $e->pkg_name eq 'RoPkg::Simba::Commands' ) {
       $self->{log}->error('Could not load command');
-      $e->rethrow;
+      return 2;
     }
     else {
       $EVAL_ERROR->rethrow;
@@ -853,16 +848,8 @@ sub _load_mirror {
     }
   }
 
-  return ($m, $c, $e);
-}
-
-sub _check_for_problems {
-  my ($self, $mirror) = @_;
-
-  if (!blessed($self)) {
-    OutsideClass->throw('Called outside class instance');
-  }
-
+  $self->RunCallbacks('afterDBLoad', $mirror);
+  
   if ( $mirror->Active == 0 ) {
     $self->{log}->error('Sorry. Mirror is not active');
     Mirror::Inactive->throw('Mirror is not active');
@@ -872,17 +859,6 @@ sub _check_for_problems {
     Mirror::InProgress->throw('Mirror is currently in progress');
   }
 
-  return 0;
-}
-
-sub _finally_run {
-  my ($self, $mirror, $command, $exclude) = @_;
-  my $cmdstr;
-
-  if (!blessed($self)) {
-    OutsideClass->throw('Called outside class instance');
-    }
-
   $self->_create_mirror_log_files($mirror);
   $self->_signal_in_progress($mirror);
   $self->{_start_time} = time;
@@ -892,43 +868,8 @@ sub _finally_run {
   $self->{log}->info('Sync ended');
   $self->_after_run($mirror);
   $self->_clean_up_files($mirror);
-  $self->_show_file_changes($mirror);
-
-  return 0;
-}
-
-sub Run {
-  my ($self, $fields) = @_;
-  my ($mirror, $command, $exclude);
-  my $cgen;
-
-  if ( !blessed($self) ) {
-    OutsideClass->throw('Called from outside class');
-  }
-    
-  ($mirror, $command, $exclude) = $self->_load_mirror($fields);
-  $self->RunCallbacks('afterDBLoad', $mirror);
-  $self->_check_for_problems($mirror);
-  $self->_finally_run($mirror, $command, $exclude);
   $self->RunCallbacks('afterSync', $mirror);
-
-  if ($mirror->LastErrorCode) {
-    $cgen = $self->{cfg}->{general};
-
-    if ($cgen->{reRunPasses}) {
-      if (   $cgen->{reRunOnError}->[0] eq '_all_'
-        || ElemInList($mirror->Name, @{ $cgen->{reRunOnError} })) {
-          for(my $i=0; $i < $cgen->{reRunPasses}; $i++) {
-            $self->{log}->info('mirror resync due to error ','(#',($i+1),')');
-            ($mirror, $command, $exclude) = $self->_load_mirror($fields);
-            $self->RunCallbacks('afterDBLoad', $mirror);
-            $self->_check_for_problems($mirror);
-            $self->_finally_run($mirror, $command, $exclude);
-            $self->RunCallbacks('afterSync', $mirror);
-          }
-      }
-    }
-  }
+  $self->_show_file_changes($mirror);
 
   return 0;
 }
@@ -947,7 +888,7 @@ RoPkg::Simba - the main class of simba
 
 =head1 VERSION
 
-0.8.4
+0.8
 
 =head1 SYNOPSIS
 
@@ -1057,10 +998,6 @@ The mirrors can be filtered using the B<$fields> parameter
 
 call the plugin methods for B<$cbName> callback name. 
 
-=head2 CheckDB()
-
-Checks if database has at least one mirror and one command defined.
-
 =head2 dbh()
 
 returns the database handler used by Simba
